pub enum MigrationCommands {
New {
name: String,
},
Pin {
migration: String,
},
Build {
pinned: bool,
migration: String,
variables: Option<String>,
},
Apply {
no_pin: bool,
migration: Option<String>,
variables: Option<String>,
yes: bool,
retry: bool,
},
Adopt {
migration: Option<String>,
yes: bool,
description: Option<String>,
},
Status,
}Variants
New
Create a new migration with the provided name
Pin
Pin a migration with current components
Build
Build a migration into SQL
Fields
Apply
Apply will apply this migration to the database if not already applied, or all migrations if called without argument.
Fields
Adopt
Mark a migration as applied without actually running it. Useful when a migration was applied manually and needs to be recorded.
Fields
Status
Show the status of all migrations