Module migration

Module migration 

Structs

AdoptMigration
ApplyMigration
BuildMigration
MigrationStatus
MigrationStatusRow
Combined status of a migration from both filesystem and database
NewMigration
PinMigration

Constants

DEFAULT_NAMESPACE

Functions

get_combined_migration_status
Get the combined status of all migrations from both filesystem and database. If namespace is None, returns migrations from all namespaces. This is shared logic that can be used by multiple commands (status, apply_all, etc.)
get_pending_and_confirm
Get pending migrations (no status, exists on filesystem) and prompt the user to confirm. Returns Ok(Some(migrations)) if confirmed, Ok(None) if aborted or empty.