Module engine

Module engine 

Modules

postgres_psql

Structs

DatabaseConfig
ExistingMigrationInfo
Information about an existing migration entry
MigrationDbInfo
Database information about a migration

Enums

CommandSpec
Specifies how to obtain the command to execute for database operations.
EngineError
Errors for streaming SQL execution
EngineType
MigrationActivity
Activity type for a migration operation
MigrationError
Errors specific to migration operations
MigrationStatus
Status of a migration in the tracking tables

Traits

Engine

Functions

resolve_command_spec
Resolves a CommandSpec to the actual command to execute.

Type Aliases

MigrationHistoryStatus
Legacy type alias for backwards compatibility
MigrationResult
Result type for migration operations
StdoutWriter
Type alias for an optional stdout writer to capture output
WriterFn
Type alias for the writer closure used in execute_with_writer