pub enum CommandSpec {
Direct {
direct: Vec<String>,
},
Provider {
provider: Vec<String>,
append: Vec<String>,
},
}Expand description
Specifies how to obtain the command to execute for database operations.
Variants
Direct
Direct command to execute
Provider
A provider command that outputs the actual command as a shell command.