resolve_command_spec

Function resolve_command_spec 

pub async fn resolve_command_spec(spec: CommandSpec) -> Result<Vec<String>>
Resolves a CommandSpec to the actual command to execute.

This is a generic function that can be used by any database engine to resolve their command specification.