pub struct EscapedLiteral { /* private fields */ }Expand description
A PostgreSQL string literal that has been safely escaped.
The value is escaped at construction time using PostgreSQL’s quote_literal rules:
- Wrapped in single quotes
- Any embedded single quotes are doubled
- If backslashes are present, prefixed with
Eand backslashes are doubled
Example
use spawn_db::escape::EscapedLiteral;
let value = EscapedLiteral::new("hello");
assert_eq!(value.as_str(), "'hello'");
let quoted = EscapedLiteral::new("it's");
assert_eq!(quoted.as_str(), "'it''s'");Implementations
Sourceimpl EscapedLiteral
impl EscapedLiteral
Sourcepub fn new(raw: &str) -> Self
pub fn new(raw: &str) -> Self
Creates a new escaped literal from a raw string.
The input is immediately escaped using PostgreSQL’s literal escaping rules.