Modules
Structs
- Migration
File Status - Filesystem-level status of a single migration.
- Store
Enums
Functions
- disk_
to_ operator - get_
migration_ fs_ status - Get the filesystem status of a single migration. Returns the status indicating whether up.sql and lock.toml files exist.
- list_
migration_ fs_ status - Scan the migrations folder and return the filesystem status of each migration, keyed by migration name. This does not touch the database. Performs a single recursive list for efficiency with remote storage.
- operator_
from_ includedir - Creates a memory-based OpenDAL operator from an include_dir bundle.
- populate_
store_ from_ store