Module telemetry

Module telemetry 

Telemetry module for anonymous usage data collection.

This module collects anonymous usage statistics to help improve spawn. It is designed to be:

  • Non-blocking: Telemetry is sent by a detached child process
  • Privacy-respecting: No personal data is collected
  • Fail-silent: Errors are silently ignored

Opt-out

Telemetry can be disabled by:

  1. Setting the DO_NOT_TRACK environment variable (any value)
  2. Setting telemetry = false in spawn.toml

Debugging

Set SPAWN_DEBUG_TELEMETRY=1 to enable debug output for telemetry.

Structs

TelemetryEvent
A telemetry event to be sent (serializable for IPC)
TelemetryRecorder
Telemetry recorder for tracking command execution.

Enums

CommandStatus
Status of command execution for telemetry

Functions

run_internal_telemetry
Run the internal telemetry handler (called by child process).
send_events
Send multiple telemetry events via a detached child process.