Structs
- Generation
- Streaming
Generation - Holds all the data needed to render a template to a writer. This struct is Send and can be moved into a WriterFn closure.
Functions
- generate_
streaming - Generate a streaming migration that can be rendered directly to a writer. This avoids materializing the entire SQL in memory.
- generate_
streaming_ with_ store - Generate a streaming migration with an existing store.
- template_
env