pub struct StreamingGeneration { /* private fields */ }Expand description
Holds all the data needed to render a template to a writer. This struct is Send and can be moved into a WriterFn closure.
Implementations
Sourceimpl StreamingGeneration
impl StreamingGeneration
Sourcepub fn render_to_writer<W: Write + ?Sized>(self, writer: &mut W) -> Result<()>
pub fn render_to_writer<W: Write + ?Sized>(self, writer: &mut W) -> Result<()>
Render the template to the provided writer. This creates the minijinja environment and renders in one step.
Sourcepub fn into_writer_fn(self) -> WriterFn
pub fn into_writer_fn(self) -> WriterFn
Convert this streaming generation into a WriterFn that can be passed to migration_apply.