Structs
- Adopt
Migration - Apply
Migration - Build
Migration - Migration
Status - Migration
Status Row - Combined status of a migration from both filesystem and database
- NewMigration
- PinMigration
Constants
Functions
- get_
combined_ migration_ status - Get the combined status of all migrations from both filesystem and database. If namespace is None, returns migrations from all namespaces. This is shared logic that can be used by multiple commands (status, apply_all, etc.)
- get_
pending_ and_ confirm - Get pending migrations (no status, exists on filesystem) and prompt the user
to confirm. Returns
Ok(Some(migrations))if confirmed,Ok(None)if aborted or empty.