Modules
Structs
- Database
Config - Existing
Migration Info - Information about an existing migration entry
- Migration
DbInfo - Database information about a migration
Enums
- Command
Spec - Specifies how to obtain the command to execute for database operations.
- Engine
Error - Errors for streaming SQL execution
- Engine
Type - Migration
Activity - Activity type for a migration operation
- Migration
Error - Errors specific to migration operations
- Migration
Status - Status of a migration in the tracking tables
Traits
Functions
- resolve_
command_ spec - Resolves a CommandSpec to the actual command to execute.
Type Aliases
- Migration
History Status - Legacy type alias for backwards compatibility
- Migration
Result - Result type for migration operations
- Stdout
Writer - Type alias for an optional stdout writer to capture output
- Writer
Fn - Type alias for the writer closure used in execute_with_writer