pub async fn resolve_command_spec(spec: CommandSpec) -> Result<Vec<String>>Expand description
Resolves a CommandSpec to the actual command to execute.
This is a generic function that can be used by any database engine to resolve their command specification.