pub struct Tester { /* private fields */ }Implementations
Sourceimpl Tester
impl Tester
pub fn new(config: &Config, script_path: &str) -> Self
pub fn test_folder(&self) -> String
pub fn test_file_path(&self) -> String
pub fn expected_file_path(&self) -> String
Sourcepub async fn generate(&self, variables: Option<Variables>) -> Result<String>
pub async fn generate(&self, variables: Option<Variables>) -> Result<String>
Opens the specified script file and generates a test script, compiled using minijinja.
pub async fn run(&self, variables: Option<Variables>) -> Result<String>
pub async fn run_compare( &self, variables: Option<Variables>, ) -> Result<TestOutcome>
pub async fn save_expected(&self, variables: Option<Variables>) -> Result<()>
Sourcepub async fn create_test(&self) -> Result<String>
pub async fn create_test(&self) -> Result<String>
Creates a new test folder with a blank test.sql file.
pub fn compare(&self, generated: &str, expected: &str) -> Result<(), String>