pub fn send_events(events: Vec<TelemetryEvent>)Expand description
Send multiple telemetry events via a detached child process.
This is useful when you have collected multiple events and want to send them all in a single child process.
pub fn send_events(events: Vec<TelemetryEvent>)Send multiple telemetry events via a detached child process.
This is useful when you have collected multiple events and want to send them all in a single child process.