Module template

Module template 

Structs

Generation
StreamingGeneration
Holds all the data needed to render a template to a writer. This struct is Send and can be moved into a WriterFn closure.

Functions

generate_streaming
Generate a streaming migration that can be rendered directly to a writer. This avoids materializing the entire SQL in memory.
generate_streaming_with_store
Generate a streaming migration with an existing store.
template_env